==> ScriptDeploy-0.4.tar: ScriptDeploy-0.4/action.editassignment.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/Cars/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

	if(!$gCms) exit();
	
	
	if(!$this->CheckPermission('Modify Templates')){
		// todo, permissions message here
		return;
	}
echo '<script type="text/javascript">
load = function() {
    load.getScript("http://ajax.microsoft.com/ajax/jQuery/jquery-1.3.2.min.js");
    // do stuff when jQuery finishes loading.
    load.tryReady(0);
}
load.getScript = function(filename) {
    var fileref = document.createElement("script")
    fileref.setAttribute("type","text/javascript")
    fileref.setAttribute("src", filename)
    if (typeof fileref!="undefined")
        document.getElementsByTagName("head")[0].appendChild(fileref)
}
load.tryReady = function(time_elapsed) {
    /* Continually polls for jQuery library. */
    if (typeof $ == "undefined") {
        if (time_elapsed <= 5000) {
            setTimeout("load.tryReady(" + (time_elapsed + 200) + ")", 200);
        } else {
            alert("Timed out while loading jQuery.")
        }
    }
}
if (typeof(window.jQuery)=="undefined"){
		load();   
}
	
	
</script>

<link media="screen" href="../modules/ScriptDeploy/CSS/MasterCSS.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="http://cdn.jquerytools.org/1.1.2/tiny/jquery.tools.min.js"></script>
<script src="http://ajax.microsoft.com/ajax/jquery.validate/1.6/jquery.validate.min.js" type="text/javascript"></script>
<script type="text/javascript" src="../modules/ScriptDeploy/includes/ME_1.00.00.js"></script>


<div id="demotip"><img class="progress" src="../modules/ScriptDeploy/images/ajax-loader.gif" alt=""/></div>

';



$MediaTypeArray=array(
		'all'=>'all',
		'aural'=>'aural',
		'braille'=>'braille',
		'handheld'=>'handheld',
		'print'=>'print',
		'embossed'=>'embossed',
		'projection'=>'projection',
		'screen'=>'screen',
		'tty'=>'tty',
		'tv'=>'tv'
);



		/*--------------------------*/
		/*----Start-----------------*/
		/*--------------------------*/
	// handle errors.
	if(isset($params['errors'])){
		echo $this->ShowErrors($params['errors']);
	}
	$active_tab="manualassignment";
	$params['origaction'] = $params['action'];
	$contents = "";
    $this->smarty->assign('formstart',
			    $this->CreateFormStart ($id, 'save_manualassignment',$returnid,'post','',false, '', $params));
	if($params['mode']=='add'){
		$this->smarty->assign('formstart',
					$this->CreateFormStart ($id, 'save_manualassignment',$returnid,'post','',false, '', $params));
		$this->smarty->assign('templatename',
				  $this->CreateInputText( $id, 'template', "", 40 ));
		$this->smarty->assign('hidden',
				  $this->CreateInputHidden($id, 'mode', $params['mode'] )
				  );
		if(isset($params['defaulttemplatepref'])&&$params['defaulttemplatepref']!=''){
			$contents = $this->GetPreference($params['defaulttemplatepref']);
		}
		
		$this->smarty->assign('submit',$this->CreateInputSubmit ($id, 'submitbutton',
							 $this->Lang ('submit')));	
		$this->smarty->assign('add','');
		$this->smarty->assign('done','');
	}else{
	
		$this->FireDebug('message','GrouptSet '.$params['GrouptSet']);//<<<<------Fire PHP message
	if(is_numeric($params['group'])){
		$Gid=$params['group'];
		$GroupID=$params['group'];
	}else{
		$Gid=$params['GrouptSet'];
		$GroupID=$params['GrouptSet'];
	}		
		
		extract($this->TieAScript('selectGroup',$Gid));
	
		$this->smarty->assign('GrouptSet',
				  $this->CreateInputText( $id, 'GrouptSet', $GrouptSet, 40, 255 ));
		$this->smarty->assign('GrouptType',
		$this->CreateInputRadioGroup ($id, 'GrouptType', array('JS'=>'JS','CSS'=>'CSS'), $GrouptType,' disabled="disabled"','')); 


//		/*--------------------------*/
//		/*---make-script-checklist--*/
//		/*--------------------------*/
		$allProfiles = $this->TieAScript('selectList');
		$ScriptPickerArray=array();
		$rowarray = array();
		$tCount=0;
		foreach($allProfiles as $key => $oneProfile ){
			$ScriptSet= $oneProfile['ScriptSet'];
			$scriptType= $oneProfile['scriptType'];
			if($scriptType==$GrouptType){
				$tCount=$tCount+1;
					$row = new StdClass();
					$row->ScriptnameLable = $ScriptSet;
					$this->FireDebug('message','for ScriptID '.$key.' GrouptSet: '.$params['GrouptSet']);//<<<<------Fire PHP message
					$row->Scriptname = $this->CreateInputCheckbox ($id, 'ScriptPicker[]', $key, $this->TieAScript('CheckScript',$key,$Gid));
					array_push ($rowarray, $row);
			}
		}
		if($tCount==0){
			$row = new StdClass();
			$row->ScriptnameLable = $this->Lang ('noneInType');
			$row->Scriptname = '';
			array_push ($rowarray, $row);
		}
		
		$this->smarty->assign('ScriptPicker', $rowarray);




		$alldbProfiles = $this->TieAScript('selectGroupsListings',$Gid);
		$rowarray = array();
		$rowclass = 'row1';
		$GrouptSize=0;
		$this->smarty->assign('formREORDERstart',
			$this->CreateFormStart ($id, 'save_manualassignment',$returnid,'post','',false, '', $params));
		
		
		foreach($alldbProfiles as $key => $onedbProfile ){
			$ScriptID= $key;
			$ScriptSet= $onedbProfile['ScriptSet'];
			$scriptSize= $onedbProfile['scriptSize'];
			$ScriptORDER= $onedbProfile['ScriptORDER'];
			$this->FireDebug('message','ScriptID '.$ScriptID);//<<<<------Fire PHP message
			$this->FireDebug('message','ScriptSet '.$ScriptSet);//<<<<------Fire PHP message
			$this->FireDebug('message','scriptSize '.$scriptSize);//<<<<------Fire PHP message

			$GrouptSize+=$scriptSize;
		
			$row = new StdClass();

			$row->name = $this->CreateLink( $id, 'edittemplate', $returnid,
							$ScriptID, array('ScriptSet' => $ScriptID,
									'active_tab' => $active_tab,
									'mode'=>'edit'));
			$row->default = $this->CreateLink( $id, 'edittemplate', $returnid,
							$ScriptSet, array('ScriptSet' => $ScriptID,
									'active_tab' => $active_tab,
									'mode'=>'edit'));
			$row->rowclass = $rowclass;
			$row->scriptSize = $this->SizeItUp($scriptSize);
			$row->orderUplink = $this->CreateLink( $id, 'orderUptemplate', $returnid,
								$gCms->variables['admintheme']->
								DisplayImage ('icons/system/arrow-u.gif',
									  $this->Lang ('edit'), '', '', 'systemicon'),
								array ('ScriptSet' => $key,
								   'active_tab' => $active_tab,
								   'mode'=>'edit'));
			$row->orderDownlink = $this->CreateLink( $id, 'orderDowntemplate', $returnid,
								$gCms->variables['admintheme']->
								DisplayImage ('icons/system/arrow-d.gif',
									  $this->Lang ('edit'), '', '', 'systemicon'),
								array ('ScriptSet' => $key,
								   'active_tab' => $active_tab,
								   'mode'=>'edit'));
			$row->ScriptORDER = $this->CreateInputText( $id, 'ScriptORDER['.$key.']', $ScriptORDER, 3, 2 );
			$row->editlink = $this->CreateLink( $id, 'edittemplate', $returnid,
								$gCms->variables['admintheme']->
								DisplayImage ('icons/system/edit.gif',
									  $this->Lang ('edit'), '', '', 'systemicon'),
								array ('ScriptSet' => $key,
								   'active_tab' => $active_tab,
								   'mode'=>'edit'));
			
			
			$row->deletelink = $this->CreateLink( $id, 'deletetemplate', $returnid,
							  $gCms->variables['admintheme']->
							  DisplayImage ('icons/system/delete.gif',
									$this->Lang ('delete'), '', '', 'systemicon'),
							  array ('ScriptSet' => $key),
							  $this->Lang ('areyousure'));
			
			
			array_push ($rowarray, $row);
			($rowclass == "row1" ? $rowclass = "row2" : $rowclass = "row1");
		}

		$this->smarty->assign('GrouptSize', $this->SizeItUp($GrouptSize));
		$this->smarty->assign('GrouptSize_label', $this->Lang('GrouptSize_label'));
		$this->smarty->assign('ScriptList', $rowarray );
			


	
	
	}
		$this->smarty->assign('add',$this->CreateInputSubmit ($id, 'submitbutton',
									 $this->Lang ('add')));
		$this->smarty->assign('Save',$this->CreateInputSubmit ($id, 'Save', 
									 $this->Lang ('Save')));
		$this->smarty->assign('REORDER',$this->CreateInputSubmit ($id, 'REORDER', $this->Lang ('REORDER')));
	//$this->smarty->assign('title',cms_html_entity_decode($params['title']));
	if($params['mode']=='add'){
		$this->smarty->assign('GrouptSet',
			$this->CreateInputText( $id, 'GrouptSet', "", 40, 255, '' ));
		$this->smarty->assign('GrouptType',
			$this->CreateInputRadioGroup ($id, 'GrouptType', array('JS'=>'JS','CSS'=>'CSS'), '','','&nbsp;&nbsp;&nbsp;')); 	
		$this->smarty->assign('ScriptPicker','');  	
		$this->smarty->assign('hiddenMode',
			$this->CreateInputHidden($id, 'mode', $params['mode'] )); 
	}
	if(isset($params['GrouptSet'])){$GID=$params['GrouptSet'];}else{$GID='X';}
	$this->FireDebug('message',$params['mode']);//<<<<------Fire PHP message
	$this->smarty->assign('hiddenMode',
			$this->CreateInputHidden($id, 'mode', $params['mode'] )
			.$this->CreateInputHidden($id, 'group', $GID )
			); 
	
	

	$this->smarty->assign('type_label', $this->Lang('type_label'));
	$this->smarty->assign('Name_label', $this->Lang('ScriptSet_label'));
	$this->smarty->assign('nameprompt_label', $this->Lang('prompt_name'));
	$this->smarty->assign('ScriptName_label', $this->Lang('ScriptName_label'));
	$this->smarty->assign('SingleCode_label', $this->Lang('SingleCode_label'));//$this->Lang('prompt_default')
	$this->smarty->assign('form_cancel', '<input type="button" value="'.$this->Lang('form_cancel').'" onclick="javascript:window.history.go(-1)" />');	  
	$this->smarty->assign('prompt_templatename',$this->Lang('prompt_templatename'));
	$this->smarty->assign('prompt_template',$this->Lang('prompt_template'));
	$this->smarty->assign('template',
				  $this->CreateSyntaxArea ($id, $contents, 'templatecontent'));
	



	$this->smarty->assign('cancel',$this->CreateInputSubmit ($id, 'cancel', 
								 $this->Lang ('Finish')));
	$this->smarty->assign('formend',$this->CreateFormEnd());

	
	
	echo $this->ProcessTemplate('editAssignment.tpl');

?>

==> ScriptDeploy-0.5.tar: ScriptDeploy-0.5/action.editassignment.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/Cars/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

	if(!$gCms) exit();
	
	
	if(!$this->CheckPermission('Modify Templates')){
		// todo, permissions message here
		return;
	}
echo '<script type="text/javascript">
load = function() {
    load.getScript("http://ajax.microsoft.com/ajax/jQuery/jquery-1.3.2.min.js");
    // do stuff when jQuery finishes loading.
    load.tryReady(0);
}
load.getScript = function(filename) {
    var fileref = document.createElement("script")
    fileref.setAttribute("type","text/javascript")
    fileref.setAttribute("src", filename)
    if (typeof fileref!="undefined")
        document.getElementsByTagName("head")[0].appendChild(fileref)
}
load.tryReady = function(time_elapsed) {
    /* Continually polls for jQuery library. */
    if (typeof $ == "undefined") {
        if (time_elapsed <= 5000) {
            setTimeout("load.tryReady(" + (time_elapsed + 200) + ")", 200);
        } else {
            alert("Timed out while loading jQuery.")
        }
    }
}
if (typeof(window.jQuery)=="undefined"){
		load();   
}
	
	
</script>

<link media="screen" href="../modules/ScriptDeploy/CSS/MasterCSS.css" type="text/css" rel="stylesheet" />
<script type="text/javascript" src="http://cdn.jquerytools.org/1.1.2/tiny/jquery.tools.min.js"></script>
<script src="http://ajax.microsoft.com/ajax/jquery.validate/1.6/jquery.validate.min.js" type="text/javascript"></script>
<script type="text/javascript" src="../modules/ScriptDeploy/includes/ME_1.00.00.js"></script>


<div id="demotip"><img class="progress" src="../modules/ScriptDeploy/images/ajax-loader.gif" alt=""/></div>

';



$MediaTypeArray=array(
		'all'=>'all',
		'aural'=>'aural',
		'braille'=>'braille',
		'handheld'=>'handheld',
		'print'=>'print',
		'embossed'=>'embossed',
		'projection'=>'projection',
		'screen'=>'screen',
		'tty'=>'tty',
		'tv'=>'tv'
);



		/*--------------------------*/
		/*----Start-----------------*/
		/*--------------------------*/
	// handle errors.
	if(isset($params['errors'])){
		echo $this->ShowErrors($params['errors']);
	}
	$active_tab="manualassignment";
	$params['origaction'] = $params['action'];
	$contents = "";
    $this->smarty->assign('formstart',
			    $this->CreateFormStart ($id, 'save_manualassignment',$returnid,'post','',false, '', $params));
	if($params['mode']=='add'){
		$this->smarty->assign('formstart',
					$this->CreateFormStart ($id, 'save_manualassignment',$returnid,'post','',false, '', $params));
		$this->smarty->assign('templatename',
				  $this->CreateInputText( $id, 'template', "", 40 ));
		$this->smarty->assign('hidden',
				  $this->CreateInputHidden($id, 'mode', $params['mode'] )
				  );
		if(isset($params['defaulttemplatepref'])&&$params['defaulttemplatepref']!=''){
			$contents = $this->GetPreference($params['defaulttemplatepref']);
		}
		
		$this->smarty->assign('submit',$this->CreateInputSubmit ($id, 'submitbutton',
							 $this->Lang ('submit')));	
		$this->smarty->assign('add','');
		$this->smarty->assign('done','');
	}else{
	

		$GrouptSet=$this->GetGroupName($params['GrouptID']);
		$Gid=$this->GetGroupID($GrouptSet);

		extract($this->TieAScript('selectGroup',$Gid));
	
		$this->smarty->assign('GrouptSet',
				  $this->CreateInputText( $id, 'GrouptSet', $GrouptSet, 40, 255 ));
		$this->smarty->assign('GrouptType',
		$this->CreateInputRadioGroup ($id, 'GrouptType', array('JS'=>'JS','CSS'=>'CSS'), $GrouptType,' disabled="disabled"','')); 


//		/*--------------------------*/
//		/*---make-script-checklist--*/
//		/*--------------------------*/
		$allProfiles = $this->TieAScript('selectList');
		$ScriptPickerArray=array();
		$rowarray = array();
		$tCount=0;
		foreach($allProfiles as $key => $oneProfile ){
			$ScriptSet= $oneProfile['ScriptSet'];
			$scriptType= $oneProfile['scriptType'];
			if($scriptType==$GrouptType){
				$tCount=$tCount+1;
					$row = new StdClass();
					$row->ScriptnameLable = $ScriptSet;
					$this->FireDebug('message','for ScriptID '.$key.' GrouptSet: '.$GrouptSet);//<<<<------Fire PHP message
					$row->Scriptname = $this->CreateInputCheckbox ($id, 'ScriptPicker[]', $key, $this->TieAScript('CheckScript',$key,$Gid));
					array_push ($rowarray, $row);
			}
		}
		if($tCount==0){
			$row = new StdClass();
			$row->ScriptnameLable = $this->Lang ('noneInType');
			$row->Scriptname = '';
			array_push ($rowarray, $row);
		}
		
		$this->smarty->assign('ScriptPicker', $rowarray);



		$alldbProfiles = $this->TieAScript('selectGroupsListings',$Gid);
		$rowarray = array();
		$rowclass = 'row1';
		$GrouptSize=0;
		$this->smarty->assign('formREORDERstart',
			$this->CreateFormStart ($id, 'save_manualassignment',$returnid,'post','',false, '', $params));
		
		
		foreach($alldbProfiles as $key => $onedbProfile ){
			$ScriptID= $key;
			$ScriptSet= $onedbProfile['ScriptSet'];
			$scriptSize= $onedbProfile['scriptSize'];
			$ScriptORDER= $onedbProfile['ScriptORDER'];
			$this->FireDebug('message','ScriptID '.$ScriptID);//<<<<------Fire PHP message
			$this->FireDebug('message','ScriptSet '.$ScriptSet);//<<<<------Fire PHP message
			$this->FireDebug('message','scriptSize '.$scriptSize);//<<<<------Fire PHP message

			$GrouptSize+=$scriptSize;
		
			$row = new StdClass();

			$row->name = $this->CreateLink( $id, 'edittemplate', $returnid,
							$ScriptID, array('ScriptSet' => $ScriptID,
									'active_tab' => $active_tab,
									'mode'=>'edit'));
			$row->default = $this->CreateLink( $id, 'edittemplate', $returnid,
							$ScriptSet, array('ScriptSet' => $ScriptID,
									'active_tab' => $active_tab,
									'mode'=>'edit'));
			$row->rowclass = $rowclass;
			$row->scriptSize = $this->SizeItUp($scriptSize);
			$row->orderUplink = $this->CreateLink( $id, 'orderUptemplate', $returnid,
								$gCms->variables['admintheme']->
								DisplayImage ('icons/system/arrow-u.gif',
									  $this->Lang ('edit'), '', '', 'systemicon'),
								array ('ScriptSet' => $key,
								   'active_tab' => $active_tab,
								   'mode'=>'edit'));
			$row->orderDownlink = $this->CreateLink( $id, 'orderDowntemplate', $returnid,
								$gCms->variables['admintheme']->
								DisplayImage ('icons/system/arrow-d.gif',
									  $this->Lang ('edit'), '', '', 'systemicon'),
								array ('ScriptSet' => $key,
								   'active_tab' => $active_tab,
								   'mode'=>'edit'));
			$row->ScriptORDER = $this->CreateInputText( $id, 'ScriptORDER['.$key.']', $ScriptORDER, 3, 2 );
			$row->editlink = $this->CreateLink( $id, 'edittemplate', $returnid,
								$gCms->variables['admintheme']->
								DisplayImage ('icons/system/edit.gif',
									  $this->Lang ('edit'), '', '', 'systemicon'),
								array ('ScriptSet' => $key,
								   'active_tab' => $active_tab,
								   'mode'=>'edit'));
			
			
			$row->deletelink = $this->CreateLink( $id, 'deletetemplate', $returnid,
							  $gCms->variables['admintheme']->
							  DisplayImage ('icons/system/delete.gif',
									$this->Lang ('delete'), '', '', 'systemicon'),
							  array ('ScriptSet' => $key),
							  $this->Lang ('areyousure'));
			
			
			array_push ($rowarray, $row);
			($rowclass == "row1" ? $rowclass = "row2" : $rowclass = "row1");
		}

		$this->smarty->assign('GrouptSize', $this->SizeItUp($GrouptSize));
		$this->smarty->assign('GrouptSize_label', $this->Lang('GrouptSize_label'));
		$this->smarty->assign('ScriptList', $rowarray );
			


	
	
	}
		$this->smarty->assign('add',$this->CreateInputSubmit ($id, 'submitbutton',
									 $this->Lang ('add')));
		$this->smarty->assign('Save',$this->CreateInputSubmit ($id, 'Save', 
									 $this->Lang ('Save')));
		$this->smarty->assign('REORDER',$this->CreateInputSubmit ($id, 'REORDER', $this->Lang ('REORDER')));
	//$this->smarty->assign('title',cms_html_entity_decode($params['title']));
	if($params['mode']=='add'){
		$this->smarty->assign('GrouptSet',
			$this->CreateInputText( $id, 'GrouptSet', "", 40, 255, '' ));
		$this->smarty->assign('GrouptType',
			$this->CreateInputRadioGroup ($id, 'GrouptType', array('JS'=>'JS','CSS'=>'CSS'), '','','&nbsp;&nbsp;&nbsp;')); 	
		$this->smarty->assign('ScriptPicker','');  	
		$this->smarty->assign('hiddenMode',
			$this->CreateInputHidden($id, 'mode', $params['mode'] )); 
	}
	if(isset($params['GrouptSet'])){$GID=$params['GrouptSet'];}else{$GID='X';}
	$this->FireDebug('message',$params['mode']);//<<<<------Fire PHP message
	$this->smarty->assign('hiddenMode',
			$this->CreateInputHidden($id, 'mode', $params['mode'] )
			.$this->CreateInputHidden($id, 'GrouptID', $GID )
			); 
	
	

	$this->smarty->assign('type_label', $this->Lang('type_label'));
	$this->smarty->assign('Name_label', $this->Lang('ScriptSet_label'));
	$this->smarty->assign('nameprompt_label', $this->Lang('prompt_name'));
	$this->smarty->assign('ScriptName_label', $this->Lang('ScriptName_label'));
	$this->smarty->assign('SingleCode_label', $this->Lang('SingleCode_label'));//$this->Lang('prompt_default')
	$this->smarty->assign('form_cancel', '<input type="button" value="'.$this->Lang('form_cancel').'" onclick="javascript:window.history.go(-1)" />');	  
	$this->smarty->assign('prompt_templatename',$this->Lang('prompt_templatename'));
	$this->smarty->assign('prompt_template',$this->Lang('prompt_template'));
	$this->smarty->assign('template',
				  $this->CreateSyntaxArea ($id, $contents, 'templatecontent'));
	



	$this->smarty->assign('cancel',$this->CreateInputSubmit ($id, 'cancel', 
								 $this->Lang ('Finish')));
	$this->smarty->assign('formend',$this->CreateFormEnd());

	
	
	echo $this->ProcessTemplate('editAssignment.tpl');

?>
